==> casagui-0.3.67-py3-none-any.whl: casagui/utils/_copydoc.py <==
########################################################################
#
# Copyright (C) 2024
# Associated Universities, Inc. Washington DC, USA.
#
# This script is free software; you can redistribute it and/or modify it
# under the terms of the GNU Library General Public License as published by
# the Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This library is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
# License for more details.
#
# You should have received a copy of the GNU Library General Public License
# along with this library; if not, write to the Free Software Foundation,
# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
#
# Correspondence concerning AIPS++ should be adressed as follows:
#        Internet email: aips2-request@nrao.edu.
#        Postal address: AIPS++ Project Office
#                        National Radio Astronomy Observatory
#                        520 Edgemont Road
#                        Charlottesville, VA 22903-2475 USA
#
########################################################################
'''Reuse doc string'''

from typing import Callable, TypeVar, ParamSpec

P = ParamSpec("P")
T = TypeVar("T")

def copydoc(src: Callable[P, T]):
    """Copy documentation from src"""

    def decorator(dest: Callable) -> Callable[P, T]:
        dest.__doc__ = src.__doc__
        return dest

    return decorator

==> casagui-0.3.74-py3-none-any.whl: casagui/utils/_copydoc.py <==
########################################################################
#
# Copyright (C) 2024
# Associated Universities, Inc. Washington DC, USA.
#
# This script is free software; you can redistribute it and/or modify it
# under the terms of the GNU Library General Public License as published by
# the Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This library is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
# License for more details.
#
# You should have received a copy of the GNU Library General Public License
# along with this library; if not, write to the Free Software Foundation,
# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
#
# Correspondence concerning AIPS++ should be adressed as follows:
#        Internet email: aips2-request@nrao.edu.
#        Postal address: AIPS++ Project Office
#                        National Radio Astronomy Observatory
#                        520 Edgemont Road
#                        Charlottesville, VA 22903-2475 USA
#
########################################################################
'''Reuse doc string'''
import os

#--------------------------------------------------
# ParamSpec is available with Python >= 3.10
#--------------------------------------------------
#from typing import Callable, TypeVar, ParamSpec
#
#P = ParamSpec("P")
#T = TypeVar("T")
#
#def copydoc(src: Callable[P, T]):
#    """Copy documentation from src"""
#
#    def decorator(dest: Callable) -> Callable[P, T]:
#        dest.__doc__ = src.__doc__
#        return dest
#
#    return decorator

def copydoc(src):
    """Copy documentation from src"""

    def decorator(dest):
        dest.__doc__ = src.__doc__
        return dest

    return decorator
